% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/create_CRU_stack.R
\name{create_CRU_stack}
\alias{create_CRU_stack}
\title{Create a List of Raster Stack Objects From CRU CL v. 2.0 Climatology Variables on Local Disk}
\usage{
create_CRU_stack(pre = FALSE, pre_cv = FALSE, rd0 = FALSE,
  tmp = FALSE, dtr = FALSE, reh = FALSE, tmn = FALSE,
  tmx = FALSE, sunp = FALSE, frs = FALSE, wnd = FALSE,
  elv = FALSE, dsn = "")
}
\arguments{
\item{pre}{Logical. Fetch precipitation (millimetres/month) from server and
return in the data frame? Defaults to \code{FALSE}.}

\item{pre_cv}{Logical. Fetch cv of precipitation (percent) from server and
return in the data frame? Defaults to \code{FALSE}. NOTE. Setting this to
\code{TRUE} will always results in \strong{pre} being set to \code{TRUE} and
returned as well.}

\item{rd0}{Logical. Fetch wet-days (number days with >0.1millimetres rain per
month) and return in the data frame? Defaults to \code{FALSE}.}

\item{tmp}{Logical. Fetch temperature (degrees Celsius) and return it in the
data frame? Defaults to \code{FALSE}.}

\item{dtr}{Logical. Fetch mean diurnal temperature range (degrees Celsius)
and return it in the data frame? Defaults to \code{FALSE}.}

\item{reh}{Logical. Fetch relative humidity and return it in the data frame?
Defaults to \code{FALSE}.}

\item{tmn}{Logical. Calculate minimum temperature values (degrees Celsius)
and return it in the data frame? Defaults to \code{FALSE}.}

\item{tmx}{Logical. Calculate maximum temperature (degrees Celsius) and
return it in the data frame? Defaults to \code{FALSE}.}

\item{sunp}{Logical. Fetch sunshine, percent of maximum possible (percent of
day length) and return it in data frame? Defaults to \code{FALSE}.}

\item{frs}{Logical. Fetch ground-frost records (number of days with ground-
frost per month) and return it in data frame? Defaults to \code{FALSE}.}

\item{wnd}{Logical. Fetch 10m wind speed (metres/second) and return it in the
data frame? Defaults to \code{FALSE}.}

\item{elv}{Logical. Fetch elevation (converted to metres) and return it in
the data frame? Defaults to \code{FALSE}.}

\item{dsn}{Local file path where \acronym{CRU} \acronym{CL} v.2.0 .dat.gz
files are located.}
}
\value{
A \code{\link[base]{list}} of \code{\link{raster}}
\code{\link[raster]{stack}} objects of \acronym{CRU} \acronym{CL} v. 2.0
climatology elements
}
\description{
Automates importing \acronym{CRU} \acronym{CL} v.2.0 climatology
data and creates a \code{\link[raster]{stack}} of the data.  If requested,
minimum and maximum temperature may also be automatically calculated as
described in the data readme.txt file.  This function can be useful if you
have network connection issues that mean automated downloading of the files
using \pkg{R} does not work properly.  In this instance it is recommended to
use an \acronym{FTP} client (\emph{e.g.}, FileZilla), web browser or command
line command (\emph{e.g.}, wget or curl) to download the files, save locally
and use this function to import the data into \pkg{R}.

Nomenclature and units from readme.txt:
\describe{
\item{pre}{precipitation (millimetres/month)}
  \describe{
    \item{cv}{cv of precipitation (percent)}
  }
\item{rd0}{wet-days (number days with >0.1mm rain per month)}
\item{tmp}{mean temperature (degrees Celsius)}
\item{dtr}{mean diurnal temperature range (degrees Celsius)}
\item{reh}{relative humidity (percent)}
\item{sunp}{sunshine (percent of maximum possible (percent of day length))}
\item{frs}{ground-frost (number of days with ground-frost per month)}
\item{wnd}{10 metre windspeed (metres/second)}
\item{elv}{elevation (automatically converted to metres)}
}
For more information see the description of the data provided by
\acronym{CRU}, \url{https://crudata.uea.ac.uk/cru/data/hrg/tmc/readme.txt}
}
\note{
This package automatically converts elevation values from kilometres to
metres.

This package crops all spatial outputs to an extent of ymin = -60, ymax = 85,
xmin = -180, xmax = 180. Note that the original wind data include land area
for parts of Antarctica, these data are excluded in the raster stacks
generated by this function.
}
\examples{
\donttest{
# Create a raster stack of temperature from tmp
# files in the tempdir() directory.

download.file(
  url = "https://crudata.uea.ac.uk/cru/data/hrg/tmc/grid_10min_tmp.dat.gz",
  destfile = file.path(tempdir(), "grid_10min_tmp.dat.gz")
)

CRU_tmp <- create_CRU_stack(tmp = TRUE, dsn = tempdir())

CRU_tmp
}

}
\seealso{
\code{\link{get_CRU_stack}}
}
\author{
Adam H. Sparks, \email{adamhsparks@gmail.com}
}
